package com.playlet.system.mapper;

import java.util.List;

import com.playlet.system.domain.PlayletUserWithdrawDepositRecord;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * @Date: 2024-03-29 23:57
 * @Author: 但星霖
 * @Version: v1.0
 * @Description: 用户交易记录Mapper接口
 */
public interface PlayletUserWithdrawDepositRecordMapper extends BaseMapper<PlayletUserWithdrawDepositRecord> {
    /**
     * 查询用户交易记录
     *
     * @param id 用户交易记录主键
     * @return 用户交易记录
     */
    PlayletUserWithdrawDepositRecord selectPlayletUserWithdrawDepositRecordById(Long id);

    /**
     * 查询用户交易记录列表
     *
     * @param playletUserWithdrawDepositRecord 用户交易记录
     * @return 用户交易记录集合
     */
    List<PlayletUserWithdrawDepositRecord> selectPlayletUserWithdrawDepositRecordList(PlayletUserWithdrawDepositRecord playletUserWithdrawDepositRecord);

    /**
     * 新增用户交易记录
     *
     * @param playletUserWithdrawDepositRecord 用户交易记录
     * @return 结果
     */
    int insertPlayletUserWithdrawDepositRecord(PlayletUserWithdrawDepositRecord playletUserWithdrawDepositRecord);

    /**
     * 修改用户交易记录
     *
     * @param playletUserWithdrawDepositRecord 用户交易记录
     * @return 结果
     */
    int updatePlayletUserWithdrawDepositRecord(PlayletUserWithdrawDepositRecord playletUserWithdrawDepositRecord);

    /**
     * 删除用户交易记录
     *
     * @param id 用户交易记录主键
     * @return 结果
     */
    int deletePlayletUserWithdrawDepositRecordById(Long id);

    /**
     * 批量删除用户交易记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deletePlayletUserWithdrawDepositRecordByIds(String[] ids);
}
